import {AdRecord} from "../records/ad.record";
import {pool} from "../utils/db";

afterAll(async () => {
    await pool.end();
});

const defaultObj = {
    name: 'Test Name',
    description: 'Test Description',
    url: 'https://example.com',
    price: 0,
    lat: 9,
    lon: 9
};

test('AdRecord.getOne returns data from database for one entry', async () => {

    const ad = await AdRecord.getOne('abc');

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('testowa');
});

test('AdRecord.getOne returns null from database for nonexistent entry', async () => {
    const ad = await AdRecord.getOne('4444g');

    expect(ad).toBeNull();
});


test('AdRecord.findAll returns array of found entries', async () => {
    const ads = await AdRecord.findAll('');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();

});

test('AdRecord.findAll returns array of found entries when searching fo "a"', async () => {
    const ads = await AdRecord.findAll('a');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();

});

test('AdRecord.findAll returns empty  array when searching fo something that does not exist', async () => {
    const ads = await AdRecord.findAll('------------------------');
    expect(ads).toEqual([]);
});

test('AdRecord.insert returns new uuid', async () => {
    const ad = new AdRecord(defaultObj);

    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
});

test('AdRecord.insert inserts data to DB', async () => {
    const ad = new AdRecord(defaultObj);
    await ad.insert();

    const foundAd = await AdRecord.getOne(ad.id);

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);


});